@@ -1,6 +1,10 @@
 #ifndef _POA_BASICS_H_
 #define _POA_BASICS_H_ 1
 
+#include <glib.h>
+
+G_BEGIN_DECLS
+
 #if !defined(_PortableServer_Servant_defined)
 #define _PortableServer_Servant_defined 1
 	typedef gpointer PortableServer_Servant;
@@ -75,4 +79,6 @@ typedef ORBitSmallSkeleton (*ORBit_small_impl_finder)
 
 #endif /* defined(ORBIT2_INTERNAL_API) || defined (ORBIT2_STUBS_API) */
 
+G_END_DECLS
+
 #endif /* _POA_BASICS_H_ 1 */
