@@ -18,7 +18,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: orbit-idl-main.c,v 1.23 2002/05/27 13:26:23 michael Exp $
+    $Id: orbit-idl-main.c,v 1.25 2002/09/04 10:38:18 mmclouglin Exp $
 
 ***************************************************************************/
 
@@ -43,10 +43,6 @@ static int cl_idlwarnlevel = 2;
 static int cl_debuglevel = 0;
 static int cl_is_pidl = 0;
 static int cl_output_version = 0;
-static int cl_enable_small = 1;
-static int cl_enable_old_style = 0;
-static int cl_enable_small_stubs = 0;
-static int cl_enable_small_skels = 0;
 static int cl_disable_idata = 0;
 static int cl_enable_imodule = 0;
 static int cl_add_imodule = 0;
@@ -54,7 +50,7 @@ static gboolean cl_disable_defs_skels = FALSE;
 static gboolean cl_showcpperrors = TRUE;
 static char *cl_output_lang = "c";
 static char *cl_header_guard_prefix = "";
-static char *cl_backend_dir = ORBITLIBDIR;
+static char *cl_backend_dir = NULL;
 static gboolean cl_onlytop = FALSE;
 static char *cl_deps_file = NULL;
 
@@ -119,8 +115,6 @@ struct poptOption options[] = {
   {"lang", 'l', POPT_ARG_STRING, &cl_output_lang, 0, "Output language (default is C)", NULL},
   {"debug", 'd', POPT_ARG_INT, &cl_debuglevel, 0, "Debug level 0 to 4", NULL},
   {"idlwarnlevel", '\0', POPT_ARG_INT, &cl_idlwarnlevel, 0, "IDL warning level 0 to 4, default is 2", NULL},
-  {"small", '\0', POPT_ARG_NONE, &cl_enable_small, 0, "Optimize for size instead of speed", NULL},
-  {"oldstyle", '\0', POPT_ARG_NONE, &cl_enable_old_style, 0, "Use the old style idl compiler", NULL},
   {"showcpperrors", '\0', POPT_ARG_NONE, &cl_showcpperrors, 0, "Show CPP errors", NULL},
   {"nostubs", '\0', POPT_ARG_NONE, &cl_disable_stubs, 0, "Don't output stubs", NULL},
   {"noskels", '\0', POPT_ARG_NONE, &cl_disable_skels, 0, "Don't output skels", NULL},
@@ -176,12 +170,6 @@ int main(int argc, const char *argv[])
 	  exit (0);
   }
 
-  if (cl_enable_old_style)
-    cl_enable_small = FALSE;
-
-  if (cl_enable_small)
-    cl_enable_small_stubs = cl_enable_small_skels = 1;
-
   /* Prep our run info for the backend */
   rinfo.cpp_args = cl_cpp_args->str;
   rinfo.debug_level = cl_debuglevel;
@@ -209,14 +197,11 @@ int main(int argc, const char *argv[])
   rinfo.header_guard_prefix = cl_header_guard_prefix;
   rinfo.backend_directory = cl_backend_dir;
   rinfo.onlytop = cl_onlytop;
-  rinfo.small = cl_enable_small_stubs || cl_enable_small_skels;
-  rinfo.small_stubs = cl_enable_small_stubs;
-  rinfo.small_skels = cl_enable_small_skels;
   rinfo.idata = !cl_disable_idata;
   
   fprintf (stderr, "orbit-idl-2 " VERSION " compiling\n");
   fprintf (stderr, " %s mode, %s preprocessor errors, passes: %s%s%s%s%s%s\n\n",
-	   rinfo.is_pidl ? "pidl" : rinfo.small ? "small" : "large",
+	   rinfo.is_pidl ? "pidl" : "",
 	   rinfo.show_cpp_errors ? "show" : "hide",
 	   cl_disable_stubs ? "" : "stubs ",
 	   cl_disable_skels ? "" : "skels ",
@@ -236,4 +221,3 @@ int main(int argc, const char *argv[])
 
   return 0;
 }
-
